==> open-xchange-subscribe_7.4.0.orig.tar.bz2: open-xchange-subscribe-7.4.0/com.openexchange.subscribe.msn/src/com/openexchange/subscribe/msn/osgi/Activator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.subscribe.msn.osgi;

import org.apache.commons.logging.Log;
import com.openexchange.log.LogFactory;
import org.osgi.util.tracker.ServiceTracker;
import com.openexchange.context.ContextService;
import com.openexchange.oauth.OAuthService;
import com.openexchange.oauth.OAuthServiceMetaData;
import com.openexchange.oauth.msn.MSNService;
import com.openexchange.osgi.HousekeepingActivator;
import com.openexchange.subscribe.SubscribeService;
import com.openexchange.subscribe.msn.MSNSubscribeService;

public class Activator extends HousekeepingActivator {

    private OAuthServiceMetaData oAuthServiceMetaData;

    private MSNService msnService;

    private static final Log LOG = com.openexchange.log.Log.valueOf(LogFactory.getLog(Activator.class));

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class[] { OAuthService.class, ContextService.class, MSNService.class};
    }

    @Override
    protected void startBundle() throws Exception {
        // react dynamically to the appearance/disappearance of OAuthMetaDataService for MSN
        rememberTracker(new ServiceTracker<OAuthServiceMetaData, OAuthServiceMetaData>(context, OAuthServiceMetaData.class.getName(), new OAuthServiceMetaDataRegisterer(context, this)));
        openTrackers();
        msnService = getService(MSNService.class);
    }

    public OAuthServiceMetaData getOAuthServiceMetaData() {
        return oAuthServiceMetaData;
    }


    public void setOAuthServiceMetaData(final OAuthServiceMetaData authServiceMetaData) {
        oAuthServiceMetaData = authServiceMetaData;
    }

    public void registerSubscribeService() {
        final MSNSubscribeService msnSubscribeService = new MSNSubscribeService(this);
        registerService(SubscribeService.class, msnSubscribeService);
        LOG.info("MSNSubscribeService was started");
    }

    public void unregisterSubscribeService() {
        unregisterServices();
        LOG.info("MSNSubscribeService was stopped");
    }


    public MSNService getMsnService() {
        return msnService;
    }


    public void setMsnService(final MSNService msnService) {
        this.msnService = msnService;
    }


}

==> open-xchange-subscribe_7.4.2.orig.tar.bz2: open-xchange-subscribe-7.4.2/com.openexchange.subscribe.msn/src/com/openexchange/subscribe/msn/osgi/Activator.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2012 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.subscribe.msn.osgi;

import org.osgi.util.tracker.ServiceTracker;
import com.openexchange.context.ContextService;
import com.openexchange.oauth.OAuthService;
import com.openexchange.oauth.OAuthServiceMetaData;
import com.openexchange.oauth.msn.MSNService;
import com.openexchange.osgi.HousekeepingActivator;
import com.openexchange.subscribe.SubscribeService;
import com.openexchange.subscribe.msn.MSNSubscribeService;

public class Activator extends HousekeepingActivator {

    private OAuthServiceMetaData oAuthServiceMetaData;

    private MSNService msnService;

    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(Activator.class);

    @Override
    protected Class<?>[] getNeededServices() {
        return new Class[] { OAuthService.class, ContextService.class, MSNService.class};
    }

    @Override
    protected void startBundle() throws Exception {
        // react dynamically to the appearance/disappearance of OAuthMetaDataService for MSN
        rememberTracker(new ServiceTracker<OAuthServiceMetaData, OAuthServiceMetaData>(context, OAuthServiceMetaData.class.getName(), new OAuthServiceMetaDataRegisterer(context, this)));
        openTrackers();
        msnService = getService(MSNService.class);
    }

    public OAuthServiceMetaData getOAuthServiceMetaData() {
        return oAuthServiceMetaData;
    }


    public void setOAuthServiceMetaData(final OAuthServiceMetaData authServiceMetaData) {
        oAuthServiceMetaData = authServiceMetaData;
    }

    public void registerSubscribeService() {
        final MSNSubscribeService msnSubscribeService = new MSNSubscribeService(this);
        registerService(SubscribeService.class, msnSubscribeService);
        LOG.info("MSNSubscribeService was started");
    }

    public void unregisterSubscribeService() {
        unregisterServices();
        LOG.info("MSNSubscribeService was stopped");
    }


    public MSNService getMsnService() {
        return msnService;
    }


    public void setMsnService(final MSNService msnService) {
        this.msnService = msnService;
    }


}
